PALM-meteo: palmmeteo_stdplugins/cams.py File Reference

PALM-meteo

Loading...
Searching...
No Matches
Classes | Namespaces | Variables
cams.py File Reference

## Classes
class | palmmeteo_stdplugins.cams.CAMSPlugin

## Namespaces
namespace | palmmeteo_stdplugins
namespace | palmmeteo_stdplugins.cams

## Variables
| palmmeteo_stdplugins.cams.ax_ = np.newaxis
| palmmeteo_stdplugins.cams.re_num = re.compile(r'[0-9\.]+')
| palmmeteo_stdplugins.cams.re_lev = re.compile(r'^.* at ([\d\.]+) meters above the surface.*$')
| palmmeteo_stdplugins.cams.re_time_nonst = re.compile(r'^.* time from (\d{8})$')